@@ -30,12 +30,12 @@ proc compile_and_run_tests { lang } {
 	lappend flags "additional_flags=-std=c++11"
     }
 
-    if { [prepare_for_testing "failed to prepare" "${binfile}" "${srcfile}" "${flags}"] } {
+    if { [prepare_for_testing "failed to prepare" $testfile $srcfile $flags] } {
 	return 0
     }
 
     # Advance to main.
-    if { ![runto_main] } then {
+    if { ![runto_main] } {
 	return 0
     }
 
